## Fatigue Increases Dynamic Knee Valgus in Youth Athletes: Results From a Field-Based Drop-Jump Test

Mohsin S. Fidai, M.D., Kelechi R. Okoroha, M.D., Jason Meldau, B.S., Fabien Meta, M.D.,
Vincent A. Lizzio, M.D., Peter Borowsky, B.S., Lauren H. Redler, M.D.,
Vasilios Moutzouros, M.D., and Eric C. Makhni, M.D., M.B.A.

Purpose: To determine whether fatigue increases dynamic knee valgus in adolescent athletes, as measured after a
standardized exercise protocol and video-based drop-jump test. A secondary aim was to determine whether individual risk
factors place certain athletes at increased risk for dynamic knee valgus. Methods: Athletes aged 14 to 18 years were
recruited for this video analysis study. Athletes were recorded performing a standard drop-jump to assess dynamic valgus.
Participants then completed a standardized exercise protocol. Fatigue was quantified using a maximum vertical jump,
which was compared with pre-exercise values. The drop-jump was repeated postexercise. All drop-jump recordings were
randomized and scored for dynamic valgus by 11 blinded reviewers. Univariate analysis was performed to identify
characteristics that predisposed athletes to increased dynamic valgus. Results: Eighty-five (47 female, 38 male) athletes
with an average age of 15.4 years were included in this study. Forty-nine percent of athletes demonstrated an increase in
dynamic valgus determined by drop-jump assessment after exercise. A significantly greater percentage of athletes were
graded “medium or high risk” in jumps recorded after the exercise protocol (68%) as compared with before the exercise
protocol (44%; P \< .01). Female athletes (P \< .01) and those older than 15 years of age (P \< .01) were the most affected by
fatigue. Conclusions: In conclusion, our study found that exercise increases dynamic knee valgus in youth athletes.
Female athletes and those older than 15 years of age were most significantly affected by exercise. Greater fatigue levels
were found to correlate with an increase in dynamic knee valgus, which may place athletes at greater anterior cruciate
ligament injury risk. The field-based exercise drop-jump test is a low-cost and reproducible screening tool to identify atrisk athletes who could possibly benefit from anterior cruciate ligament injury-prevention strategies. Level of Evidence: III, Comparative trial.

[See commentary on page 223](<http://www.arthroscopyjournal.org/article/S0749-8063(19)30872-2/abstract>)

# More than 120,000 anterior cruciate ligament(ACL) injuries occur every year, with the ma

jority of injuries occurring in high school athletes. \[1\] The
Centers for Disease Control and Prevention estimates

From the Henry Ford Health System, Detroit, Michigan (M.S.F., J.M.,
F.M., V.A.L., P.B., V.M., E.C.M); Rush University Medical Center, Chicago,
Illinois (K.R.O.); and Columbia University Medical Center, New York, New
York (L.H.R.), U.S.A.
The authors report the following potential conflicts of interest or sources of
funding: E.C.M. reports other from Smith and Nephew, and from Springer,
outside the submitted work. This study was approved by the Henry Ford
Health System Institutional Review Board IRB #10786. Full ICMJE author
disclosure forms are available for this article online, as supplementary
material.

Received August 13, 2018; accepted July 9, 2019.
Address correspondence to Eric C. Makhni, M.D., M.B.A., Orthopedics - 3rd
Floor East, 6777 West Maple, West Bloomfield, MI 48322. E-mail:
[emakhni1@hfhs.org](mailto:emakhni1@hfhs.org)

� 2019 by the Arthroscopy Association of North America
0749-8063/18991/$36.00
[https://doi.org/10.1016/j.arthro.2019.07.018](https://doi.org/10.1016/j.arthro.2019.07.018)

that in 2006 the total financial impact of ACL reconstruction was nearly $1 billion to the US health system. \[2\]

The vast majority of ACL injuries are categorized as
noncontact injuries, with 70% of noncontact injuries
occurring when landing from a jump. \[3\] It is also well
established in the literature that there is an increased

risk of ACL injury in female patients compared with
male patients. \[4-6\] Several factors can predispose an individual to ACL injury, including genetic predisposition,
sex, hormone levels in female patients, narrow femoral
notch width, poor neuromuscular control, and landing
biomechanics. \[2,5\] Of the known risk factors, neuromuscular control and landing biomechanics are modifiable risk factors. \[7-10\]

In 2005, Hewett et al. \[11\] found that an increased
knee valgus angle during a drop-jump correlated with
increased ACL injury risk. This drop-jump test has
since been used as a tool to identify athletes who are
lacking lower-limb control and who may benefit from

214 Arthroscopy: The Journal of Arthroscopic and Related Surgery, Vol 36, No 1 (January), 2020: pp 214-222

FATIGUE INCREASES DYNAMIC KNEE VALGUS 215

neuromuscular training. Historically, the drop-jump
test required the use of sophisticated computerized
motion-analysis systems with marker technology to
determine precise knee valgus angles. However, in
2016, Redler et al. \[12\] validated a field-based drop-jump
test as a reliable and reproducible method to identify
an individual with poor lower limb neuromuscular
control. The authors found that lower-limb neuromuscular control using a field-based drop-jump could
be adequately assessed by physicians, physical therapists, athletic trainers, and coaches without significant
training in motion-capture technology. The sensitivity
of the field-based drop-jump for determining
medium-or high-risk athletes was found to be 95%. \[12\]

Appendix 1 outlines the previous study’s findings.
Although previous studies have suggested that lowerextremity muscle fatigue is a risk factor for ACL
injury, \[13-17\] the precise impact of fatigue on injury risk
to the ACL is still unknown. A recent systematic review
attempted to measure this risk; however, no correlation
could be found, in part due to the heterogeneity of
testing protocols and tasks identified. \[18\] Therefore, a
more thorough investigation of the effect of fatigue on
ACL injury risk is required.
The primary purpose of this study was to determine
whether fatigue increases dynamic knee valgus in
adolescent athletes, as measured after a standardized
exercise protocol and video-based drop-jump test. A
secondary aim was to determine whether individual
risk factors could be identified that pose certain athletes
at risk for dynamic knee valgus. We hypothesized that
athlete fatigue would lead to an increase in dynamic
knee valgus in adolescent athletes as determined by a
field-based, drop jump test.

Materials and Methods

We performed a prospective, diagnostic study after
approval from our institutional review board. Students
who were high school athletes at the time of the study
were consented for participation. Athletes younger
than the age of 18 years provided consent by a parent
or guardian and the participant also provided approval.
These athletes were directly recruited through 4 partner
schools affiliated with the health system by members of
the research study team.
Inclusion criteria for the study included being 18 years
of age or younger, active participation in high school
athletics, and agreement to participate in the study. Athletes were excluded if they had active knee pain, previous
knee surgery, history of patellar instability, lowerextremity neuromuscular disorder, or visible knee effusion. Athletes completed an intake form detailing history
of any current or previous musculoskeletal injuries.
The field drop-jump test was performed in a similar
manner to the previously validated study by Redler
et al. \[12\] A digital video recording device was positioned

on a stand that was 40 inches in height and 12 feet
away from the drop-jump box. The drop-jump box
comprised a square platform 15 inches in width and 12
inches tall. The setup was consistent with previous
studies. \[12,19,20\] Athlete fatigue was determined objectively by percent reduction in maximum vertical jump.
To measure maximum vertical jump, athletes were
instructed to jump with maximum effort and tag a
sticker to a tape-measure placed on a wall. The
maximum vertical jump was recorded in inches. White
circular marker/stickers were placed on the participant’s anterior superior iliac spine, patella, tibial
tubercle, and the center of the ankle. \[12,21\] Athletes then
completed 3 drop-jumps, which were video recorded.
For the drop-jump, athletes were instructed to stand
with their feet shoulder width apart, drop off of the box
onto a marker 12 inches in front of the box, land on
their feet facing forward, and immediately perform a
maximum vertical jump.
Following baseline testing, athletes were instructed to
complete a standardized exercise protocol consisting of a
timed period of high-intensity aerobic task, instructed to
be performed at maximum intensity. The protocol was
created by the study team and was modeled after previous
studies. \[22-24\] The goal was to create a circuit of plyometric
exercises, with comparable short durations, while using
minimal equipment. The protocol was created to be
applicable to average high school athletes, both male and
female. In addition, the protocol was designed to be
implemented in a short period of time regardless of athletic
knowledge or ability by medical personnel or athletes.
The protocol employed by this study consisted of
1 minute of jumping jacks, 30 seconds of jump squats, a
1-minute plank, and 30 seconds of alternating lunge
jumps. Athletes were instructed to exert maximum
effort during the exercise protocol. Terms such as
“game speed” were used to highlight desired effort.
Immediately after completion of the exercise protocol,
athletes were instructed to complete another maximum
vertical jump, which was used to quantify fatigue. A
decrease in maximum vertical jump of at least 20% was
considered a fatigued state. The use of before-and-after
jumping tasks to quantify level of fatigue has been used
in previous studies, albeit with variation. \[22-24\] Athletes
then completed 3 postexercise drop-jump tests immediately following the postexercise vertical jump. Postexercise jumps were also video recorded (Fig 1).
Video observers consisted of physical therapists, athletic trainers, and senior orthopaedic surgery residents.
Observers were recruited from local colleges as well as
through the orthopaedic department and department of
physical therapy. A total of 11 observers were included
in this study. All observers received a $50 Amazon gift
card (Seattle, WA) as compensation.
Two of the authors (F.M. and V.A.L.) reviewed the 3
pre-exercise and postexercise drop jump videos of all

216 M. S. FIDAI ET AL.

participants and choose the highest quality test from
each (based on compliance with instructions) for
observer analysis. There were a total of 170 drop-jump
videos from the 85 athletes (85 pre-exercise, and 85
postexercise) Observers were sent 2 secure links via
e-mail to 2 websites containing videos of the athletes
completing the drop-jump tests along with an online
survey for each video, a method previously used by
Redler et al. \[12\] Videos were separated by sex to decrease
bias. One video contained pre- and postexercise dropjumps of the 38 male athletes and the other video
contained the 47 female athletes. The videos were

randomized, and the observers were blinded to the fatigue status of each participant. Each observer (11 total)
reviewed all selected video clips. Observers were
instructed to watch and rate the male videos before

watching and rating the female videos. Videos were
separated by sex to help reduce bias. All observers were
given a detailed instruction sheet with information

Fig 2. Field-based drop-jump
assessment. Figure displaying
examples of (A) low dynamic
valgus and (B) a high dynamic
valgus.

Fig 1. Drop-jump testing protocol. The testing protocol is
described. (ASIS, anterior superior iliac spine.)

about the drop-jump test and instructions on the classification of low-, medium-, or high-risk test (see
Appendix 1). Observers were then asked to rate each
jump video as either “low,” “medium,” or “high”
dynamic valgus (Fig 2). Our protocol was based on the
previously validated study using drop jump by Redler
et al. \[12\] All ratings for each athlete’s pre-/postexercise
jumps were aggregated, and the most common rating
was assigned to determine 1 pre- and 1 postexercise
classification for the athlete. An increase in dynamic
valgus was determined to be an increase in rating from
pre-exercise testing to postexercise testing (i.e., low- to
medium or high-risk, or medium- to high-risk).

Statistical Analysis
The primary outcome of the study was to determine
whether a correlation exists between athlete fatigue
and dynamic knee valgus during a field drop-jump test.
Descriptive statistics of demographics are presented

FATIGUE INCREASES DYNAMIC KNEE VALGUS 217

using means, standard deviations (SDs), and ranges. All
continuous data are described using means and SDs,
whereas categorical data are described using counts and
column percentages. The c \[2\] or Fisher exact test was
used to compare categorical variables between groups,
including the proportion of patients with increased risk
compared before and after exercise. Intraclass correlation coefficients were used to determine the agreement
in ratings between judges. Although arbitrary, the
agreement classifications for intraclass correlation
coefficients have been described as \<0.40: poor; 0.40 to
0.60: fair; 0.60 to 0.74: good, and >0.75: strong. \[25\]

Univariate analysis was employed to identify factors
that predisposed athletes to increased dynamic valgus; P
value is calculated by the KruskaleWallis test for numerical covariates and Fisher exact test for categorical
covariates. Subgroup analysis was conducted based on
sex, age group, and athletes who increased in risk
following exercise (n ¼ 38). Risk factors assessed
included height, weight, body mass index, vertical
jump/change in vertical jump, and fatigue level. Statistical significance was set at P \< .05. All analyses were
performed using SAS 9.4 (SAS Institute, Cary, NC).

Results

One hundred ten athletes were recruited for participation in the study; 23 athletes declined to participate.
Two athletes were excluded. One athlete had a previous arthroscopic medial meniscus repair and the other
had a history of a medial collateral ligament repair. A
total of 85 athletes (47 female and 38 male) were
included in this study. The average age of the athletes
was 15.4 years (range 13-18 years). Participants
included in the study consisted of track and field,
basketball, volleyball, and soccer athletes. Demographic
data of the athletes are presented in Table 1. Eleven
observers reviewed and rated the videos. Three re
viewers were senior orthopaedic surgery residents
(M.D.), 4 were certified athletic trainers (A.T.-C.), and 4
were physical therapists (P.T.). The interobserver reliability between observers in this study was found to be
0.5 (95% confidence interval 0.41-0.58) in the preexercise group and 0.6 (95% confidence interval
0.50-0.67) in the postexercise group.
Following exercise, 22 (26%) of the 85 athletes
reached a 20% reduction of maximal vertical jump.
After completing the exercise protocol, on average,
there was a 15.4% (SD 11.7%) reduction in maximum
vertical jump height. Thirty-eight athletes (44.7%)
demonstrated an increase in dynamic knee valgus
following exercise. Level of fatigue was found to
correlate with degree of dynamic knee valgus. In patients with greater than or equal to 20% fatigue
(as indicated by a decrease in maximum vertical
height), 63.6% (14/22) of athletes demonstrated an
increase in risk stratification versus only 38.1% (24/63)

Table 1. Participant Demographic Characteristics

All Female Male

N ¼ 85 n ¼ 47 n ¼ 38 P Value

Age, y (SD) 15.4 (3.9) 15.1 (4.4) 15.7 (2.9) .46
Height, cm (SD) 173.2 (8.3) 168.1 (5.3) 179.7 (6.8) \<.01
Weight, kg (SD) 65.5 (11.7) 62.6 (9.8) 69.0 (13.0) .01
BMI, SD 22.0 (3.3) 22.2 (3.3) 21.3 (3.2) .20

NOTE. T test P values are displayed. Bold P values are statistically
significant.
BMI, body mass index; SD, standard deviation.

of athletes with less than 20% fatigue, P ¼ .04 (Fig 3).
Furthermore, univariate analysis on athletes with
increased risk stratification demonstrated that the
fatigued state (>20% decrease in vertical jump) was the
only predictor for an increase in dynamic knee valgus
(Table 2). A multivariate analysis was not included in
the manuscript because the sample size for athletes
with increased in risk (n ¼ 38) was too small for reliable
analysis.
There was a significant increase in the proportion of
athletes ranked medium or high risk postexercise
compared with pre-exercise (68% vs 44%; P \< .01, c \[2\]

test). Similarly, a significantly greater proportion of
female athletes (P \< .01) and athletes �15 years old
(P \< .01) were rated medium/high risk following the
exercise protocol compared to pre-exercise (Table 3).
However, when a univariate analysis was run on all
players, sex and age group were not found to be significant predictors (Table 4). A post-hoc power analysis
revealed that to detect fatigue as an independent predictor of increased risk with 80% power, 175 patients
would have been required.

Discussion

The results of our study indicate that fatigue increases
dynamic knee valgus in youth and adolescent athletes,
as measured through a drop-jump test protocol.
Moreover, we found female athletes and those athletes
older than the age of 15 to be more likely to demonstrate increased dynamic knee valgus.
Several studies have suggested that fatigue alters
lower-limb biomechanics, \[26-28\] leading to an increased
risk of ACL injury. \[14,29,30\] However, there are inconsistencies between these studies in regards to fatigue
protocols, athletic tasks studied, and the effects of fatigue
on lower extremity joint angles. \[18\] In 2005, Mandelbaum
et al. \[31\] studied the effectiveness of neuromuscular and

proprioceptive training in preventing ACL injuries. They
reported 88% fewer ACL injuries in athletes enrolled in
neuromuscular training compared with the control
group. Subsequent studies have demonstrated similar
improvements in lower-extremity biomechanics and
ACL injury risk reduction. \[9,32,33\] However, despite the
extensive implementation of ACL injury-prevention

218 M. S. FIDAI ET AL.

Fig 3. Percentage of athletes with increased dynamic valgus after fatigue.

programs, there has not been a corresponding decrease
in the incidence of ACL injury. \[4,34-36\] Our study found a
significant increase in dynamic knee valgus after exercise. This change in lower-limb neuromuscular control
was found to correlate with the amount of fatigue, as
athletes demonstrating more than 20% fatigue were
significantly more likely to have increased dynamic knee
valgus. Many of the current neuromuscular training
programs for ACL injury prevention do not account for
the deleterious effects of fatigue on lower-limb biomechanics. The findings of this study advocate for ACL
injury prevention training programs to incorporate
fatigue resistance training and for fatigue awareness by
coaches, trainers, and physical education teachers.
Although this study did not evaluate the cost effectiveness of implementing fatigue-driven drop-jump
assessments in relation to injury prevention, there is
utility in targeting at-risk athletes. Although universal
enrollment of all athletes into neuromuscular training
has been shown to be a cost-effective strategy in
reducing societal ACL injury cost burden, it can still
require significant time otherwise devoted to

conditioning or sport-specific training. \[37\] Evidencebased prevention programs recommend starting
6 weeks before competition and can require maintenance programs during the season. \[38,39\] Therefore,
effective selection of athletes in need of a time-intensive

neuromuscular training can be facilitated by fatigue
enhanced drop-jump assessments.
Subgroup analysis from this study revealed that there
was a significant increase in the number of female
athletes that were categorized as medium- or high-risk
for ACL injury based on dynamic knee valgus after
fatigue. A similar finding was demonstrated in older
athletes as well (age >15 years). This is in line with
previous studies, which have shown that female
patients have a greater rate of ACL injury, with
commonly cited risk factors such as smaller ligament
size, posterior-inferior slope of the lateral tibia plateau,
increased knee and generalized laxity, and increased
body mass index. \[4-6\] In addition, greater injury rates
have been reported in girls following puberty. \[40-42\] This
may be due to the musculoskeletal changes associated
with maturation, leading to poorer neuromuscular

Table 2. Univariate Analysis of Athletes Who Increased in Risk Following Exercise

Covariate No Increase in Risk n ¼ 47 Increased in Risk n ¼ 38 P Value\*

Sex, n (%)
Female 23 (48.94) 24 (63.16) .273
Male 24 (51.06) 14 (36.84)
Height, cm, mean (SD) 174.7 (9.2) 171.4 (6.8) .117
Weight, kg, mean (SD) 66.1 (13.1) 64.7 (9.8) .825
BMI, mean (SD) 21.5 (3.1) 22.1 (3.5) .524
Vertical jump pre-exercise, inches, mean (SD) 16.9 (6.8) 14.8 (3.8) .339
Vertical jump postexercise, inches, mean (SD) 14.7 (6.5) 12.3 (3.7) .114
Age group, y, n (%)
�15 26 (57.78) 18 (51.43) .653

> 15 19 (42.22) 17 (48.57)
> Change in vertical jump (%), mean (SD) �13.7 (10.1) �17.4 (13.2) .318
> Fatigued (change in vertical �20%), n (%)
> No 39 (82.98) 24 (63.16) .048
> Yes 8 (17.02) 14 (36.84)

BMI, body mass index; SD, standard deviation.
\*The nonparametric P value is calculated by the KruskaleWallis test for numerical covariates and the Fisher exact test for categorical covariates.
Bold P values are statistically significant.

FATIGUE INCREASES DYNAMIC KNEE VALGUS 219

Table 3. Percent of Athletes With Medium/High Dynamic
Valgus Pre- and Postexercise

Pre-Exercise, Postexercise,
Athletes Percent (n) Percent (n) P Value

All 43.5% (37) 68.2% (58) \<.01
Female 40.4% (19) 72.3% (34) \<.01
Male 48.6% (18) 64.9% (24) .16
�15 y 52.3% (21) 68.2% (30) .13

> 15 y 30.6% (11) 66.7% (24) \<.01

NOTE. c \[2\] test P values are displayed. Bold P values are statistically
significant.

control and landing mechanics in female athletes. \[43,44\]

As the majority of the athletes in the current study
are female, this could also explain why our study found
older adolescent athletes to be categorized as greaterrisk athletes. Our study cannot conclude a direct relationship between fatigued athletes who were female or
older and ACL injury. However, these groups are
impacted by fatigue in terms of dynamic knee valgus,
which has been shown to correlate with increased ACL

injury risk.
It is important to mention that the assessment of ACL
injury risk using dynamic knee valgus is imperfect.
There are several factors at play that influence final
landing position, such as center of gravity of the trunk/
lower extremities, trunk-hip adduction or abduction
position, foot-ankle pronation-supination position, and
foot separation distance. Previous studies using the

Table 4. Univariate Comparisons by Sex and Age Group

drop-jump also identify this limitation. \[12,20\] To account
for all these factors, a sophisticated motion-analysis and
video capture system in several planes of motion are
required and thus not feasible outside of a laboratory.
Regardless, the field-based drop-jump test using a
single-camera system in the coronal plane has been
shown to be a valid screening tool. The test, when
evaluating medium- and high-risk athletes, has a high
sensitivity (95%) with high inter-rater (k ¼ 0.92) and
moderate intra-rater (k ¼ 0.55) reliabilities. \[12\] As a
screening tool, the drop jump’s high sensitivity is
desirable. In the current study, the number of athletes
determined to have either medium- or high- amount of
dynamic knee valgus significantly increased after
exercise. This indicates that the addition of an exercise

protocol before the drop-jump test may increase the
sensitivity of the screening tool. However, further
investigation is required to objectively determine sensitivities and specificities of an exercise-based drop
jump compared with a standard drop jump assessment.

Limitations

There are several limitations to this study. First, we
attempted to recreate a field-based test with video
recordings. Subtle variances appreciated during a live
drop-jump test that influence an observer’s rating may
be lost in a video. However, this testing and grading
protocol has been used previously and demonstrated
strong accuracy. \[12\] Second, the exercise protocol used in

Covariate Female n ¼ 47 Male n ¼ 38 P Value \[*\] Age �15 y n ¼ 44 Age >15 y n ¼ 36 P Value \[*\]

Height, cm, mean (SD) 168.1 (5.3) 179.7 (6.8) \<.001 170.9 (7.2) 176.6 (8.7) .003
Weight, kg, mean (SD) 62.6 (9.8) 69.0 (13.0) .013 62.9 (13.6) 68.7 (8.1) \<.001
BMI, mean (SD) 22.2 (3.3) 21.3 (3.2) .151 21.5 (3.7) 22.1 (2.3) .077
Vertical jump pre-exercise, inches, mean (SD) 12.5 (2.2) 20.3 (5.8) \<.001 13.8 (3.1) 18.9 (7.0) \<.001
Vertical jump postexercise, inches, mean (SD) 10.5 (2.5) 17.4 (5.8) \<.001 11.8 (3.1) 16.4 (6.8) \<.001
Pre-exercise risk, n (%)
Low 28 (59.57) 20 (52.63) .660 21 (47.73) 25 (69.44) .069
Medium/high 19 (40.43) 18 (47.37) 23 (52.27) 11 (30.56)
Postexercise risk, n (%)
Low 13 (27.66) 14 (36.84) .483 14 (31.82) 12 (33.33) 1.000
Medium/high 34 (72.34) 24 (63.16) 30 (68.18) 24 (66.67)
Change in risk, n (%)
None 22 (46.81) 22 (57.89) .417 24 (54.55) 18 (50) .856
Increased 24 (51.06) 14 (36.84) 18 (40.91) 17 (47.22)
Decreased 1 (2.13) 2 (5.26) 2 (4.55) 1 (2.78)
Increase in risk, n (%)
No 23 (48.94) 24 (63.16) .273 26 (59.09) 19 (52.78) .653
Yes 24 (51.06) 14 (36.84) 18 (40.91) 17 (47.22)
Change in vertical jump (%), mean (SD) �15.9 (13.6) �14.6 (8.8) .714 �15.0 (9.8) �13.9 (12.8) .523
Fatigued (change in vertical �20%), n (%)
No 32 (68.09) 31 (81.58) .158 33 (75) 29 (80.56) .601
Yes 15 (31.91) 7 (18.42) 11 (25) 7 (19.44)

NOTE. Five athletes declined to provide their ages.
BMI, body mass index; SD, standard deviation.
\*The nonparametric P value is calculated by the KruskaleWallis test for numerical covariates and Fisher exact test for categorical covariates.
Bold P values are statistically significant.

220 M. S. FIDAI ET AL.

this study was designed by the authors, as a validated
protocol for this testing context was not available.
However, despite being a novel protocol, we did identify a drop in maximum vertical jump following the
exercise protocol in most athletes, indicating ability to
induce leg fatigue. Previous investigations in the literature have used 20% reduction in jumping ability to
quantify fatigue induced by their respective protocol. \[22,23\] Although this was our benchmark to define a
fatigued state as well, we decided to carry out the
postexercise drop-jump assessment, regardless if an
athlete reached 20% fatigue threshold or not. We
accepted less than 20% fatigue levels to analyze
whether the level of fatigue had a relationship to
increased dynamic knee valgus. Furthermore, our study
was not designed to evaluate the sensitivity of a
fatigued field-based drop-jump test; therefore, we
cannot comment whether a fatigued state makes the
drop jump a more sensitive test. The triplets of pre- and
postfatigue videos were reviewed by 2 of the authors in
a similar blinded manner described in the Methods. The

highest quality of each were chosen for observer review
based on video quality and instruction adherence. This
was done to lessen the burden of observer review;
however, it can be a source of bias. In addition, the
interobserver reliability was determined to be fair and
intraobserver reliability was not measured in this study.
A larger number of observers may have increased this
reliability measure. Although the interobserver reliabilities in this study are not as strong as what was
originally published by Redler et al., this is likely a
product of the relatively low number of observers used
in this study. Redler et al. enrolled 242 observers to
validate the reliability of the test successfully. Demonstrating the drop jump’s reliability as a qualitative
assessment for dynamic knee valgus was not an
objective for this study. Lastly, we did not control for
footwear. Athletes without athletic shoes were

excluded, but this was the only control of footwear.
This may have had some impact on results. We suspect
this difference would be of limited significance, however. The drop jump was conducted on even flat,
ground in basketball gyms; this likely helps negate some
of the influence of footwear.

Conclusions

In conclusion, our study found that exercise increases
dynamic knee valgus in youth athletes. Female athletes
and those older than 15 years of age were most
significantly affected by exercise. Greater fatigue levels
were found to correlate with an increase in dynamic
knee valgus, which may place athletes at greater ACL
injury risk. The field-based exercise drop-jump test is a
low-cost and reproducible screening tool to identify
at-risk athletes who could possibly benefit from ACL
injury-prevention strategies.

References

1. Gornitzky AL, Lott A, Yellin JL, Fabricant PD,
   [Lawrence JT, Ganley TJ. Sport-specific yearly risk and](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref1>)
   [incidence of anterior cruciate ligament tears in high](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref1>)
   [school athletes: A systematic review and meta-analysis.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref1>)
   [Am J Sports Med 2016;44:2716-2723.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref1>)
   [2. Kaeding CC, Leger-St-Jean B, Magnussen RA. Epidemi-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref2>)
   [ology and diagnosis of anterior cruciate ligament injuries.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref2>)
   [Clin Sports Med 2017;36:1-8.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref2>)
   [3. Hewett TE, Ford KR, Xu YY, Khoury J, Myer GD. Utili-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref3>)
   [zation of ACL injury biomechanical and neuromuscular](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref3>)
   [risk profile analysis to determine the effectiveness of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref3>)
   neuromuscular training. [Am](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref3>) J Sports Med 2016;44:

[3146-3151.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref3>)

[4. Agel J, Arendt EA, Bershadsky B. Anterior cruciate liga-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref4>)
[ment injury in national collegiate athletic association](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref4>)
[basketball and soccer: A 13-year review. Am J Sports Med](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref4>)
[2005;33:524-530.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref4>)
[5. Lin CY, Casey E, Herman DC, Katz N, Tenforde AS. Sex](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref5>)
[differences in common sports injuries. PM R 2018;10:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref5>)

[1073-1082.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref5>)

[6. Mihata LC, Beutler AI, Boden BP. Comparing the inci-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref6>)
[dence of anterior cruciate ligament injury in collegiate](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref6>)
[lacrosse, soccer, and basketball players: Implications for](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref6>)
[anterior cruciate ligament mechanism and prevention.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref6>)
[Am J Sports Med 2006;34:899-904.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref6>)
[7. Myer GD, Ford KR, McLean SG, Hewett TE. The effects of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref7>)
[plyometric versus dynamic stabilization and balance](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref7>)
[training on lower extremity biomechanics. Am J Sports](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref7>)
[Med 2006;34:445-455.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref7>)
[8. Myer GD, Ford KR, Palumbo JP, Hewett TE. Neuromus-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref8>)
[cular training improves performance and lower-extremity](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref8>)
[biomechanics in female athletes. J Strength Cond Res](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref8>)
[2005;19:51-60.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref8>)
[9. Sugimoto D, Myer GD, Foss KD, Hewett TE. Specific](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref9>)
[exercise effects of preventive neuromuscular training](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref9>)
[intervention on anterior cruciate ligament injury risk](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref9>)
[reduction in young females: Meta-analysis and subgroup](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref9>)
[analysis. Br J Sports Med 2015;49:282-289.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref9>)
10\. Zazulak BT, Hewett TE, Reeves NP, Goldberg B,
[Cholewicki J. Deficits in neuromuscular control of the](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref10>)
trunk predict knee [injury](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref10>) risk: A prospective
[biomechanical-epidemiologic study. Am J Sports Med](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref10>)
[2007;35:1123-1130.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref10>)
[11. Hewett TE, Myer GD, Ford KR, et al. Biomechanical](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref11>)
[measures of neuromuscular control and valgus loading of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref11>)
[the knee predict anterior cruciate ligament injury risk in](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref11>)
[female athletes: A prospective study. Am J Sports Med](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref11>)
[2005;33:492-501.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref11>)
[12. Redler LH, Watling JP, Dennis ER, Swart E, Ahmad CS.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref12>)
[Reliability of a field-based drop vertical jump screening](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref12>)
[test for ACL injury risk assessment. Phys Sportsmed](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref12>)
[2016;44:46-52.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref12>)
[13. Behrens M, Mau-Moeller A, Wassermann F, Plewka A,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref13>)
[Bader R, Bruhn S. Repetitive jumping and sprinting until](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref13>)
[exhaustion alters hamstring reflex responses and tibial](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref13>)
[translation in males and females. J Orthop Res 2015;33:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref13>)

[1687-1692.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref13>)

[14. Borotikar BS, Newcomer R, Koppes R, McLean SG.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref14>)
[Combined effects of fatigue and decision making on](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref14>)

FATIGUE INCREASES DYNAMIC KNEE VALGUS 221

[female lower limb landing postures: Central and periph-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref14>)
[eral contributions to ACL injury risk. Clin Biomech (Bristol,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref14>)
[Avon) 2008;23:81-92.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref14>)
[15. Kernozek TW, Torry MR, VANH H, Cowley H, Tanner S.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref15>)
[Gender differences in frontal and sagittal plane biome-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref15>)
[chanics during drop landings. Med Sci Sports Exerc 2005;37:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref15>)
[1003-1012. discussion 1013.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref15>)

[16. McLean SG, Fellin RE, Suedekum N, Calabrese G,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref16>)
[Passerallo A, Joy S. Impact of fatigue on gender-based](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref16>)
[high-risk landing strategies. Med Sci Sports Exerc 2007;39:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref16>)

[502-514.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref16>)

[17. Liederbach M, Kremenic IJ, Orishimo KF, Pappas E,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref17>)
[Hagins M. Comparison of landing biomechanics between](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref17>)
[male and female dancers and athletes, part 2: Influence of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref17>)
[fatigue and implications for anterior cruciate ligament](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref17>)
[injury. Am J Sports Med 2014;42:1089-1095.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref17>)
[18. Barber-Westin SD, Noyes FR. Effect of fatigue protocols](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref18>)
[on lower limb neuromuscular function and implications](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref18>)
[for anterior cruciate ligament injury prevention training:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref18>)
[A systematic review. Am J Sports Med 2017;45:3388-3396.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref18>)
[19. Barber-Westin SD, Noyes FR, Galloway M. Jump-land](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref19>)
[characteristics and muscle strength development in young](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref19>)
[athletes: A gender comparison of 1140 athletes 9 to 17](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref19>)
[years of age. Am J Sports Med 2006;34:375-384.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref19>)
[20. Noyes FR, Barber-Westin SD, Fleckenstein C, Walsh C,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref20>)
[West J. The drop-jump screening test: Difference in lower](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref20>)
[limb control by gender and effect of neuromuscular](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref20>)
[training in female athletes. Am J Sports Med 2005;33:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref20>)

[197-207.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref20>)

[21. Myer GD, Ford KR, Khoury J, Succop P, Hewett TE.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref21>)
[Development and validation of a clinic-based prediction](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref21>)
[tool to identify female athletes at high risk for anterior](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref21>)
[cruciate ligament injury. Am J Sports Med 2010;38:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref21>)

[2025-2033.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref21>)

[22. Dickin DC, Johann E, Wang H, Popp JK. Combined effects](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref22>)
[of drop height and fatigue on landing mechanics in active](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref22>)
[females. J Appl Biomech 2015;31:237-243.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref22>)
[23. Lessi GC, Serrao FV. Effects of fatigue on lower limb,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref23>)
[pelvis and trunk kinematics and lower limb muscle ac-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref23>)
[tivity during single-leg landing after anterior cruciate lig-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref23>)
[ament reconstruction. Knee Surg Sports Traumatol Arthrosc](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref23>)
[2017;25:2550-2558.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref23>)
[24. Wesley CA, Aronson PA, Docherty CL. Lower extremity](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref24>)
[landing biomechanics in both sexes after a functional](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref24>)
[exercise protocol. J Athl Train 2015;50:914-920.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref24>)
[25. Hazra A, Gogtay N. Biostatistics series module 6: Corre-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref25>)
[lation and linear regression. Indian J Dermatol 2016;61:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref25>)

[593-601.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref25>)

[26. Cortes N, Greska E, Ambegaonkar JP, Kollock RO,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref26>)
[Caswell SV, Onate JA. Knee kinematics is altered post-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref26>)
[fatigue while performing a crossover task. Knee Surg](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref26>)
[Sports Traumatol Arthrosc 2014;22:2202-2208.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref26>)
[27. Santamaria LJ, Webster KE. The effect of fatigue on](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref27>)
[lower-limb biomechanics during single-limb landings: A](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref27>)
[systematic review. J Orthop Sports Phys Ther 2010;40:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref27>)

[464-473.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref27>)

[28. Thomas AC, Lepley LK, Wojtys EM, McLean SG, Palmieri-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)
[Smith RM. Effects of neuromuscular fatigue on quadri-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)
[ceps strength and activation and knee biomechanics in](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)

[individuals post-anterior cruciate ligament reconstruction](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)
[and healthy adults. J Orthop Sports Phys Ther 2015;45:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)

[1042-1050.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref28>)

[29. Benjaminse A, Habu A, Sell TC, et al. Fatigue alters lower](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref29>)
[extremity kinematics during a single-leg stop-jump task.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref29>)
[Knee Surg Sports Traumatol Arthrosc 2008;16:400-407.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref29>)
[30. Kernozek TW, Torry MR, Iwasaki M. Gender differences](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref30>)
in lower extremity [landing](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref30>) mechanics caused by
neuromuscular fatigue. [Am](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref30>) J Sports Med 2008;36:

[554-565.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref30>)

[31. Mandelbaum BR, Silvers HJ, Watanabe DS, et al. Effec-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref31>)
[tiveness of a neuromuscular and proprioceptive training](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref31>)
[program in preventing anterior cruciate ligament injuries](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref31>)
[in female athletes: 2-year follow-up. Am J Sports Med](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref31>)
[2005;33:1003-1010.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref31>)
[32. Petersen W, Braun C, Bock W, et al. A controlled](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref32>)
[prospective case control study of a prevention training](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref32>)
[program in female team handball players: The German](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref32>)
experience. Arch Orthop Trauma Surg 2005;125:

[614-621.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref32>)

[33. Sugimoto D, Myer GD, Barber Foss KD, Pepin MJ,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref33>)
[Micheli LJ, Hewett TE. Critical components of neuro-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref33>)
[muscular training to reduce ACL injury risk in female](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref33>)
athletes: Meta-regression [analysis.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref33>) Br J Sports Med
[2016;50:1259-1266.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref33>)
[34. Brophy RH, Stepan JG, Silvers HJ, Mandelbaum BR.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref34>)
[Defending puts the anterior cruciate ligament at risk](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref34>)
[during soccer: A gender-based analysis. Sports Health](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref34>)
[2015;7:244-249.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref34>)
[35. Deitch JR, Starkey C, Walters SL, Moseley JB. Injury risk](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref35>)
in professional basketball players: a comparison of
[Women’s National Basketball Association and National](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref35>)

[Basketball Association athletes. Am J Sports Med 2006;34:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref35>)

[1077-1083.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref35>)

[36. Joseph AM, Collins CL, Henke NM, Yard EE, Fields SK,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref36>)
[Comstock RD. A multisport epidemiologic comparison of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref36>)
[anterior cruciate ligament injuries in high school athletics.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref36>)
[J Athl Train 2013;48:810-817.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref36>)
[37. Swart E, Redler L, Fabricant PD, Mandelbaum BR,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref37>)
[Ahmad CS, Wang YC. Prevention and screening programs](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref37>)
[for anterior cruciate ligament injuries in young athletes: A](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref37>)
[cost-effectiveness analysis. J Bone Joint Surg Am 2014;96:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref37>)

[705-711.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref37>)

[38. Acevedo RJ, Rivera-Vega A, Miranda G, Micheo W.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref38>)
[Anterior cruciate ligament injury: Identification of risk](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref38>)
[factors and prevention strategies. Curr Sports Med Rep](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref38>)
[2014;13:186-191.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref38>)
[39. Alentorn-Geli E, Myer GD, Silvers HJ, et al. Prevention of](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref39>)
[non-contact anterior cruciate ligament injuries in soccer](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref39>)
[players. Part 2: A review of prevention programs aimed to](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref39>)
[modify risk factors and to reduce injury rates. Knee Surg](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref39>)
[Sports Traumatol Arthrosc 2009;17:859-879.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref39>)
[40. Shea KG, Pfeiffer R, Wang JH, Curtin M, Apel PJ. Anterior](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref40>)
[cruciate ligament injury in pediatric and adolescent soccer](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref40>)
[players: An analysis of insurance data. J Pediatr Orthop](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref40>)
[2004;24:623-628.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref40>)
[41. Stracciolini A, Stein CJ, Zurakowski D, Meehan WP 3rd,](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref41>)
[Myer GD, Micheli LJ. Anterior cruciate ligament injuries](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref41>)
[in pediatric athletes presenting to sports medicine clinic: A](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref41>)

222 M. S. FIDAI ET AL.

[comparison of males and females through growth and](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref41>)
[development. Sports Health 2015;7:130-136.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref41>)
[42. Quatman CE, Ford KR, Myer GD, Hewett TE. Maturation](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref42>)
[leads to gender differences in landing force and vertical](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref42>)
[jump performance: A longitudinal study. Am J Sports Med](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref42>)
[2006;34:806-813.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref42>)

[43. Chidi-Ogbolu N, Baar K. Effect of estrogen on musculo-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref43>)
[skeletal performance and injury risk. Front Physiol 2018;9:](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref43>)

[1834.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref43>)

[44. Sayer TA, Hinman RS, Paterson KL, et al. Differences](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref44>)
[in hip and knee landing moments across female pu-](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref44>)
bertal development. Med Sci Sports Exerc 2019;51:

[123-131.](<http://refhub.elsevier.com/S0749-8063(19)30661-9/sref44>)

FATIGUE INCREASES DYNAMIC KNEE VALGUS 222.e1

Appendix 1
Anterior Cruciate Ligament Injury Screening Test:
Observer Education Sheet

Introduction

The primary objective of this study is to use a simple
clinical test, the drop jump, to identify young athletes at
risk for injury to their anterior cruciate ligament (ACL).
Research has shown individuals at risk for ACL injury
demonstrate poor neuromuscular control of their lower
limbs, which can be observed during dynamic activities
like running, cutting, stopping, and jumping. In the
jump drop test, a subject jumps off a 12-inch high box,
landing directly in front of it, and immediately performs
a maximum vertical jump. At-risk individuals land from
the jump fundamentally differently than those not at
risk. As an observer, you will watch a video of athletes
performing the drop jump test and will classify each
athlete risk level as “high,” “medium,” or “low.” This
document will demonstrate what a “high-risk” versus a
“low-risk” landing looks like. Medium risk can be
applied to athletes who do not fit in either of these
categories.
Note: it is NOT necessary for all components of the
“high-risk” jump to be present for the “high-risk” jump.

The “High-Risk” Jump:
The landing is less smooth, more rigid, in forceful. The
subject may not land evenly on the balls of their feet
but may be off balance on their heels. The feet may land
in a narrow stance, substantially less than shoulder
width apart. The knees may appear "knock-kneed,"
known as valgus alignment. The knees and hips are not
flexed as much contributing to a rough landing.

1. Off balance/heel landing
1. Narrow landing stance
1. Valgus (“knock-knee”) alignment
1. Poor kneecap separation distance
1. Knees and hips not flexed enough

222.e2 M. S. FIDAI ET AL.

The “Low-Risk” Jump:
The athlete lands with a coordinated, balanced,
smooth landing. The subject lands on the balls of their
feet, with the feet approximately shoulder width apart
or wider. The knees do not bend in toward the midline

of the individual, but rather stay in neutral alignment
with the kneecap approximately in line with the ankles
and hips with good separation distance between the

kneecaps. The knees and hips are both bent to facilitate
a smooth landing.

1. Landing evenly on balls of feet
1. Landing with feet shoulder width apart
1. Neutral alignment of knees
1. Good separation distance between kneecaps
1. Knees and hips flexed
